@@ -1,5 +1,5 @@
 fn main() {
-    #[cfg(capstone_bench)]
+    #[cfg(feature="capstone_bench")]
     {
         println!("cargo:rustc-link-search=/usr/lib/");
         println!("cargo:rustc-link-lib=capstone");
